//	This work is licensed under the Creative Commons Attribution-ShareAlike 3.0 Unported License.
//	To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/3.0/ or send a
//	letter to Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.

//	Persistence of Vision Ray Tracer version 3.8 Include File
//	File: KeywordExamples.inc
//	Last updated: 2021.3.7
/*	Description: Companion file for: Code examples for all of the keywords in SDL
			pigments
			color_maps
			textures
			functions
			macros
			scene setup for rendering: such as camera and other extensive code
*/

//-------10--------20--------30--------40--------40--------50--------60--------70--------80--------100

			#declare xy = x + y;
			#declare xz = x + z;
			#declare yz = y + z;
			
// Bald Eagle
			#declare E = 0.000001;
			#declare V_Unit = <1, 1, 1>;
			#declare V_Half = 0.5 * V_Unit;
			#declare T_Red = texture {pigment {rgb <0.50, 0.00, 0.00>}}
			#declare T_Grn = texture {pigment {rgb <0.00, 0.50, 0.00>}}
			#declare T_Blu = texture {pigment {rgb <0.00, 0.00, 0.50>}}
			#declare T_Yel = texture {pigment {rgb <0.55, 0.55, 0.00>}}
			#declare T_Blk = texture {pigment {rgb <0.00, 0.00, 0.00>}}	
			#declare T_Wht = texture {pigment {rgb <1.00, 1.00, 1.00>}}	
			#declare P_White = pigment {rgb <1, 1, 1>}
			#declare P_Gray = pigment {rgb <1, 1, 1>*0.5}
// end Bald Eagle

#macro BasicScene (Center, SkySphereColor)	
	camera {
		location  Center-z*20
		right     x*image_width/image_height
		up 		y
		look_at   Center
	}
	sky_sphere {pigment {SkySphereColor}}
	light_source {Center-z*20 color rgb 1}
#end // end macro BasicScene


#macro OrthoScene (Center, SkySphereColor, Zoom)
	//#local Zoom = 1;   // this many pixels will cover 1 pov unit	
	camera {
		orthographic
		location  Center-(z*20)
		right     x*image_width/Zoom
		up 		y*image_height/Zoom
		look_at   Center
	}
	sky_sphere {pigment {SkySphereColor}}
	light_source {Center-z*20 color rgb 1}
#end // end macro OrthoScene

#macro GraphCircularEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	// Bald Eagle 2021
	sphere {0 Line texture {T_Wht}}
	torus {1 Line texture {T_Wht} }
	union {
		#for (XX, Xmin, Xmax, Step)
			#local Current = <XX, Function (XX), 0>;
			sphere {Current Line}
		#end // end for XX
		texture {T_Blu}
		no_shadow
	} // end union
#end // end macro GraphCircularEquation

#macro GraphLinearEquation (Function, Xmin, Xmax, Ymin, Ymax, Step, Line)
	// Bald Eagle 2021
	sphere {0 Line texture {T_Wht}}
	cylinder {x*Xmin, x*Xmax Line texture {T_Red} }
	cylinder {y*Ymin, y*Ymax Line texture {T_Grn} }
	#local NotFirstPoint = false;
	union {
		#for (XX, Xmin, Xmax, Step)
			#local Current = <XX, Function (XX), 0>;
			sphere {Current Line}
			#if (NotFirstPoint)
				cylinder {Last, Current Line}
			#end // end if
			#declare Last = Current;
			#local NotFirstPoint = true;
		#end // end for XX
		texture {T_Blu}
		no_shadow
	} // end union
#end // end macro GraphLinearEquation

